=======
Credits
=======

Development Lead
----------------

* `Michael Goerz`_ <mail@michaelgoerz.net>


Development Team
----------------

* Daniel Basilewitsch <basilewitsch@physik.uni-kassel.de>
* Fernando Gago Encinas <fernando.gago@fu-berlin.de>
* Matthias Krauß <matthias.krauss@physik.uni-kassel.de>
* Karl Horn <karlhorn@physik.uni-kassel.de>
* `Daniel Reich`_ <danreich@zedat.fu-berlin.de>
* `Christiane Koch`_ <christiane.koch@fu-berlin.de>

.. _Michael Goerz: https://michaelgoerz.net
.. _Daniel Reich: https://www.physik.fu-berlin.de/en/einrichtungen/ag/ag-koch/Mitarbeiterinnen/reich/index.html
.. _Christiane Koch: https://www.physik.fu-berlin.de/en/einrichtungen/ag/ag-koch/index.html


Acknowledgements
----------------

We thank
`Alberto Castro`_,
`@TejasAvinasShetty`_,
`@nathanshammah`_,
`@timohillmann`_,
`@loganbvh`_,
`@uiofgh`_, and
`@zachmanson`_,
for reporting bugs and suggesting improvements.

.. _Alberto Castro: https://www.bifi.es/~acastro/
.. _@loganbvh: https://github.com/loganbvh
.. _@zachmanson: https://github.com/zachmanson
.. _@TejasAvinasShetty: https://github.com/TejasAvinashShetty
.. _@nathanshammah: https://github.com/nathanshammah
.. _@timohillmann: https://github.com/timohillmann
.. _@uiofgh: https://github.com/uiofgh
